@@ -1,9 +1,10 @@
-#' Get the object currently being played on the user’s Spotify account.
+#' @title Get the object currently being played on the user’s Spotify account.
 #'
 #' @param market An ISO 3166-1 alpha-2 country code or the string \code{"from_token"}.
-#' Provide this parameter if you want to apply \
-#' href{https://developer.spotify.com/documentation/general/guides/track-relinking-guide/}{Track Relinking}
-#' @param authorization Required. A valid access token from the Spotify Accounts service. See the \href{https://developer.spotify.com/documentation/general/guides/authorization-guide/}{Web API authorization guide} for more details. Defaults to \code{spotifyr::get_spotify_access_token()}. The access token must have been issued on behalf of the current user. \cr
+#' Provide this parameter if you want to apply
+#' \href{https://developer.spotify.com/documentation/general/guides/track-relinking-guide/}{Track Relinking}
+#' @param authorization Required. A valid access token from the Spotify Accounts service. See the \href{https://developer.spotify.com/documentation/general/guides/authorization-guide/}{Web API authorization guide} for more details.
+#' Defaults to \code{spotifyr::get_spotify_access_token()}. The access token must have been issued on behalf of the current user. \cr
 #' The access token must have the
 #' \code{user-read-currently-playing} and/or \code{user-read-playback-state} scope authorized in order to read information.
 #' @return
@@ -114,8 +115,14 @@ get_my_devices <- function(authorization = get_spotify_authorization_code()) {
 
 #' Get information about the user’s current playback state, including track, track progress, and active device.
 #'
-#' @param market An ISO 3166-1 alpha-2 country code or the string \code{"from_token"}. Provide this parameter if you want to apply \href{https://developer.spotify.com/documentation/general/guides/track-relinking-guide/}{Track Relinking}
-#' @param authorization Required. A valid access token from the Spotify Accounts service. See the \href{https://developer.spotify.com/documentation/general/guides/authorization-guide/}{Web API authorization Guide} for more details. Defaults to \code{spotifyr::get_spotify_access_token()}. The access token must have been issued on behalf of the current user. \cr
+#' @param market An ISO 3166-1 alpha-2 country code or the string \code{"from_token"}.
+#' Provide this parameter if you want to apply
+#' \href{https://developer.spotify.com/documentation/general/guides/track-relinking-guide/}{Track Relinking}.
+#' @param authorization Required. A valid access token from the Spotify Accounts service.
+#' See the \href{https://developer.spotify.com/documentation/general/guides/authorization-guide/}{Web API authorization Guide}
+#' for more details.
+#' Defaults to \code{spotifyr::get_spotify_access_token()}.
+#' The access token must have been issued on behalf of the current user. \cr
 #' The access token must have the \code{user-read-playback-state} scope authorized in order to read information.
 #' @return
 #' Returns a list containing user playback information. See the official Spotify Web API
@@ -143,9 +150,9 @@ get_my_current_playback <- function(market = NULL,
   res
 }
 
-#' Pause Playback
+#' @title Pause Playback
 #'
-#' Pause playback on the user’s device.
+#' @description Pause playback on the user’s device.
 #'
 #' @param device_id Optional. The id of the device this command is targeting.
 #' If not supplied, the user’s currently active device is the target.
@@ -172,7 +179,7 @@ pause_my_playback <- function(device_id = NULL,
     res
 }
 
-#' Toggle shuffle on or off for user’s playback.
+#' @title Toggle shuffle on or off for user’s playback.
 #'
 #' @param state Required. \cr
 #' \code{TRUE}: Shuffle user's playback \cr
@@ -213,9 +220,9 @@ toggle_my_shuffle <- function(state,
     res
 }
 
-#' Set User Playback Mode
+#' @title Set User Playback Mode
 #'
-#' Set the repeat mode for the user’s playback.
+#' @description Set the repeat mode for the user’s playback.
 #' Options are repeat-track, repeat-context, and off.
 #'
 #' @param state Required. \cr
@@ -252,16 +259,18 @@ set_my_repeat_mode <- function(state,
   res
 }
 
-#' Set User Device Volume
+#' @title Set User Device Volume
 #'
-#' Set the volume for the user’s current playback device.
+#' @description Set the volume for the user’s current playback device.
 #'
 #' @param volume_percent Required integer value. The volume to set.
 #'  Must be a value from 0 to 100 inclusive. Defaults to \code{50}.
 #' @param device_id Optional. The id of the device this command is targeting.
 #' If not supplied, the user’s currently active device is the target.
 #' @param authorization Required. A valid access token from the Spotify Accounts service.
-#' See the \href{https://developer.spotify.com/documentation/general/guides/authorization-guide/}{Web API authorization Guide} for more details. Defaults to \code{spotifyr::get_spotify_access_token()}. The access token must have been issued on behalf of the current user. \cr
+#' See the \href{https://developer.spotify.com/documentation/general/guides/authorization-guide/}{Web API authorization Guide}
+#' for more details. Defaults to \code{spotifyr::get_spotify_access_token()}.
+#' The access token must have been issued on behalf of the current user. \cr
 #' The access token must have the \code{user-modify-playback-state} scope authorized in order
 #' to control playback.
 #' @return The response from the Spotify Web API on the \code{PUT} request, with a meaningful
@@ -288,9 +297,9 @@ set_my_volume <- function(volume_percent = 50,
   res
 }
 
-#' Skips to Next Track
+#' @title Skips to Next Track
 #'
-#' Skips to next track in the user’s queue.
+#' @description Skips to next track in the user’s queue.
 #'
 #' @param device_id Optional. The id of the device this command is targeting. If not supplied,
 #' the user’s currently active device is the target.
@@ -320,7 +329,7 @@ skip_my_playback <- function(device_id = NULL,
     res
 }
 
-#' Skips to previous track in the user’s queue.
+#' @title Skips to previous track in the user’s queue.
 #'
 #' @param device_id Optional. The id of the device this command is targeting. If not supplied, the user’s currently active device is the target.
 #' @param authorization Required. A valid access token from the Spotify Accounts service. See the \href{https://developer.spotify.com/documentation/general/guides/authorization-guide/}{Web API authorization Guide} for more details. Defaults to \code{spotifyr::get_spotify_access_token()}. The access token must have been issued on behalf of the current user. \cr
@@ -347,7 +356,7 @@ skip_my_playback_previous <- function(device_id = NULL,
 
 }
 
-#' Skips to previous track in the user’s queue.
+#' @title Skips to previous track in the user’s queue.
 #'
 #' @param device_id Optional. The id of the device this command is targeting. If not supplied, the user’s currently active device is the target.
 #' @param context_uri Optional. String of the Spotify URI of the context to play. Valid contexts are albums, artists, playlists. Example \code{context_uri = "spotify:album:1Je1IMUlBXcx1Fz0WE7oPT"}.
@@ -384,7 +393,7 @@ start_my_playback <- function(device_id = NULL,
   )
   body_params <- list(
     context_uri = context_uri,
-    uris = uris,
+    uris = I(uris),
     offset = offset,
     position_ms = position_ms
   )
@@ -397,7 +406,7 @@ start_my_playback <- function(device_id = NULL,
   res
 }
 
-#' Transfer playback to a new device and determine if it should start playing.
+#' @title Transfer playback to a new device and determine if it should start playing.
 #'
 #' @param device_ids Required. A character vector containing the ID of the device this on which playback should be started/transferred. Note: only a single device_id is currently supported.
 #' @param play Optional. \cr
